@@ -19,6 +19,18 @@ void lwpInitContext(newp, sp)
 	newp->context[0] = (int)lwpEntryPoint;
 }
 
+#elif defined(FBSD)
+
+void lwpInitContext(newp, sp)
+        struct lwpProc *newp;
+        void *sp;
+{
+        setjmp (newp->context);
+        newp->context->_jb[2] = (int)sp;
+        newp->context->_jb[3] = (int)sp;
+        newp->context->_jb[0] = (int)lwpEntryPoint;
+}
+
 #elif defined(__linux__)
 
 void lwpInitContext(newp, sp)
