@@ -19,6 +19,7 @@ static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/update/
 #include "var.h"
 #include "budg.h"
 #include "edb.h"
+#include "product.h"
 
 #include <sys/time.h>
 
@@ -68,10 +69,13 @@ update_main(argc, argv)
 			continue;
 		money[n] = np->nat_money;
 	}
+
 	prepare_sects(etu, bp);
 	for (x=0; x<MAXNOC; x++){
 		int	y,z,sb=0,sm=0,pb=0,pm=0,lm=0,lb=0;
+		long    p_sect[SCT_MAXDEF+1][2];
 
+		bzero((s_char *)p_sect, sizeof(p_sect));
 		mil_dbl_pay = 0;
 		if ((np = getnatp(x)) == (struct natstr *)0)
 			continue;
@@ -81,12 +85,13 @@ update_main(argc, argv)
 #endif
 		   continue;
 		} 
-		np->nat_money += (int) (np->nat_reserve * money_res);
+		np->nat_money += (int) (np->nat_reserve * money_res * etu);
+
 		for(y=1; y<SCT_MAXDEF+8; y++) {
 			for(z=0; z<SCT_MAXDEF+8; z++) {
 				if (np->nat_priorities[z] == y)
-					do_prod(z, etu, x, bp, &sb, &sm, &pb, 
-						&pm, &lb, &lm);
+					do_prod(z, etu, x, bp, p_sect, &sb, 
+						&sm, &pb, &pm, &lb, &lm);
 			}
 		}
 		/* 0 is maintain, 1 is build */
@@ -97,8 +102,10 @@ update_main(argc, argv)
 		if (!lm) prod_land(etu, x, bp, 0);
 		if (!lb) prod_land(etu, x, bp, 1);
 		/* produce all sects that haven't produced yet */
-		produce_sect(x, etu, -1);
+		produce_sect(x, etu, bp, p_sect, -1);
+		np->nat_money -= p_sect[SCT_CAPIT][1];
 	}
+
 	finish_sects();
 	prod_nat(etu);
 	age_levels(etu);
@@ -146,9 +153,9 @@ update_main(argc, argv)
 	/*NOTREACHED*/
 }
 
-do_prod(sector_type,etu,n,bp,ship_build,ship_maint,plane_build,plane_maint,land_build,land_maint)
+do_prod(sector_type,etu,n,bp,p_sect,ship_build,ship_maint,plane_build,plane_maint,land_build,land_maint)
 	int sector_type;
-	int n,*bp,*ship_build,*ship_maint;
+	int n,*bp,*p_sect,*ship_build,*ship_maint;
 	int *plane_build,*plane_maint;
 	int *land_build,*land_maint;
 {
@@ -189,62 +196,7 @@ do_prod(sector_type,etu,n,bp,ship_build,ship_maint,plane_build,plane_maint,land_
 		*land_build=1;
 	}
 	else
-		produce_sect(n,etu,sector_type);
-}
-
-int
-bud_key(comm)
-        int   comm;
-{
-        int   key_table[I_MAX+2] = {0,1,2,3,4,0,0,0,0,0,0,5,6,0,0,7};
-
-	return key_table[comm];
-}
-
-int
-bud_ckey(comm)
-        int   comm;
-{
-        int   ckey_table[8] = {0,I_CIVIL,I_MILIT,I_SHELL,I_GUN,I_LCM,I_HCM,0};
-
-	return ckey_table[comm];
-}
-
-int
-*get_wp(bp, sp, comm)
-        int   *bp;
-        struct sctstr *sp;
-        int   comm;
-{
-        int   cm;
-
-	if ((cm = bud_key(comm)) == 0)
-	  return bp; /* Someone could have fun with civs...*/
-        return (bp + (sp->sct_x + (sp->sct_y * WORLD_X)) + WORLD_X * WORLD_Y * (cm - 1));
-}
-
-int
-gt_bg_nmbr(bp, sp, comm)
-        int   *bp;
-        struct sctstr *sp;
-        int   comm;
-{
-        int   *wp;
-
-	wp = get_wp(bp, sp, comm);
-	return *wp;
-}
-
-void pt_bg_nmbr(bp, sp, comm, amount)
-        int   *bp;
-        struct sctstr *sp;
-        int   comm;
-        int   amount;
-{
-        int   *wp;
-
-	wp = get_wp(bp, sp, comm);
-	*wp = amount;
+		produce_sect(n,etu,bp,p_sect,sector_type);
 }
 
 static
