@@ -224,6 +224,7 @@ shiprepair(ship, vec, np, bp, etus)
 	int	w_p_eff;
 	int	mult;
 	int	svec[I_MAX+1];
+	int     mvec[I_MAX+1];
 	int	rel;
 
 	mp = &mchr[ship->shp_type];
@@ -317,116 +318,25 @@ shiprepair(ship, vec, np, bp, etus)
 		left = delta;
 
         leftp = ((float)left/100.0);
-        lcm_needed = ldround((double)(mp->m_lcm * leftp),1);
-        hcm_needed = ldround((double)(mp->m_hcm * leftp),1);
+	bzero(mvec, sizeof(mvec));
+        mvec[I_LCM] = lcm_needed = ldround((double)(mp->m_lcm * leftp),1);
+        mvec[I_HCM] = hcm_needed = ldround((double)(mp->m_hcm * leftp),1);
 
-	if (opt_GRAB_THINGS) {
-		/* try_supply_commod will get from this sect first, then look
-		 * elsewhere until it finds what it needs. It'll return the
-		 * number of mil/lcm/hcm/etc it finds available without
-		 * actually getting it
-		 */
+	get_materials(sp, bp, mvec, 0);
 
-		getvec(VT_ITEM, vec, (s_char *)ship, EF_SHIP);
-		lcm = vec[I_LCM];
-		hcm = vec[I_HCM];
-
-		lcm += try_supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,I_LCM,
-					 lcm_needed-lcm);
-		hcm += try_supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,I_HCM,
-					 hcm_needed-hcm);
-	}
-	else			/* don't GRAB_THINGS */
-	{
-	        if (update_pending) {
-		  lcm = svec[I_LCM];
-		  hcm = svec[I_HCM];
-		} else {
-		  sp = getsectp(ship->shp_x, ship->shp_y);
-		  lcm = gt_bg_nmbr(bp, sp, I_LCM);
-		  hcm = gt_bg_nmbr(bp, sp, I_HCM);
-		}
-	} /* GRAB_THINGS */
-
-        if (lcm>=lcm_needed)
+        if (mvec[I_LCM]>=lcm_needed)
                 buildp=leftp;
         else
-                buildp=((float)lcm/(float)mp->m_lcm);
-        if (hcm < hcm_needed)
-                buildp = MIN(buildp,((float)hcm/(float)mp->m_hcm));
+                buildp=((float)mvec[I_LCM]/(float)mp->m_lcm);
+        if (mvec[I_HCM] < hcm_needed)
+                buildp = MIN(buildp,((float)mvec[I_HCM]/(float)mp->m_hcm));
 
 	build=ldround((double)(buildp*100.0),1);
+	bzero(mvec, sizeof(mvec));
+        mvec[I_LCM] = lcm_needed = roundavg((double)(mp->m_lcm * buildp));
+        mvec[I_HCM] = hcm_needed = roundavg((double)(mp->m_hcm * buildp));
 
-        lcm_needed = roundavg((double)(mp->m_lcm * buildp));
-        hcm_needed = roundavg((double)(mp->m_hcm * buildp));
-
-	if (opt_GRAB_THINGS) {
-		/*
-		 * Now that we know how much we can actually use, get it.
-		 * supply_commod will actually subtract the commod off the
-		 * sector/ship/supply unit
-		 */
-		lcmo = lcm = vec[I_LCM];
-		hcmo = hcm = vec[I_HCM];
-
-		/* Take the commods off so supply_commod doesn't grab them */
-		/* keepmil, etc are how many they should have afterwards   */
-
-		keeplcm=(lcm-lcm_needed > 0 ? lcm-lcm_needed : 0);
-		keephcm=(hcm-hcm_needed > 0 ? hcm-hcm_needed : 0);
-
-		vec[I_LCM]=0;
-		vec[I_HCM]=0;
-		
-		putvec(VT_ITEM, vec, (s_char *)ship, EF_SHIP);
-
-		lcm += supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,I_LCM,
-				     lcm_needed-lcm);
-		hcm += supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,I_HCM,
-				     hcm_needed-hcm);
-	      
-	        if (update_pending) {
-		  vec[I_LCM]=keeplcm;
-		  vec[I_HCM]=keephcm;
-		} else {
-		  vec[I_LCM]=lcmo;
-		  vec[I_HCM]=hcmo;
-		}
-		putvec(VT_ITEM, vec, (s_char *)ship, EF_SHIP);
-
-		/*
-		 * get the sect again, so we don't
-		 * overwrite it if supply_commod changed it
-		 */
-		sp = getsectp(ship->shp_x, ship->shp_y);
-	}
-	else			/* dont GRAB_THINGS */
-	{
-		if ((lcm - lcm_needed) < 0){
-		        if (update_pending)
-			   svec[I_LCM] = 0;
-			else
-			   pt_bg_nmbr(bp, sp, I_LCM, 0);
-       		}else{
-		        if (update_pending)
-			   svec[I_LCM] -= lcm_needed;
-			else
-			   pt_bg_nmbr(bp,sp,I_LCM,gt_bg_nmbr(bp,sp,I_LCM)-lcm_needed);
-		}
-		if ((hcm - hcm_needed) < 0){
-		        if (update_pending)
-			   svec[I_HCM] = 0;
-			else
-			   pt_bg_nmbr(bp, sp, I_HCM, 0);
-		}else{
-		        if (update_pending)
-			   svec[I_HCM] -= hcm_needed;
-			else
-			   pt_bg_nmbr(bp,sp,I_HCM,gt_bg_nmbr(bp,sp,I_HCM)-hcm_needed);
-		}
-		if (update_pending)
-		  putvec(VT_ITEM, svec, (s_char *)sp, EF_SECTOR);
-	} /* GRAB_THINGS */
+	get_materials(sp, bp, mvec, 1);
 
 	if (sp->sct_type != SCT_HARBR)
 		build = delta;
